@@ -1,7 +1,7 @@
 /* CatalystX::CRUD::YUI custom JavaScript 
 
 # sync with .pm files
-my $VERSION = '0.017';   
+my $VERSION = '0.018';   
 
 */
 YAHOO.namespace('crud');
@@ -1325,13 +1325,14 @@ YAHOO.crud.wysiwygify = function( textareaId, textareaTitle ) {
     // make sure the 'save' button writes changes to textarea
     YAHOO.crud.onFormSubmit.push(
      function() {
+        myEditor.saveHTML();   // save gui content in screen to object
         var editorText = myEditor.get('textarea').value;
         var textareaText = Dom.get(textareaId).value;
         //alert(textareaId + " textarea: " + editorText);
         if (editorText != textareaText) {
             alert("editor text mismatch: " + editorText + ' <> ' + textareaText);
         }
-        myEditor.saveHTML();
+        //myEditor.saveHTML();  // do this first above.
         if (editorText.length) {
             myEditor.get('textarea').value = editorText.replace(/<br>/gi, '\n');
         }
